@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008001;
 use FFI::Platypus 0.56;
-use FFI::Platypus::DL;
+use FFI::Platypus::DL qw( dlopen dlerror RTLD_NOW RTLD_GLOBAL );
 use FFI::CheckLib qw( find_lib );
 use base qw( Exporter );
 use constant NEWRELIC_RETURN_CODE_OK                      => 0;
@@ -19,10 +19,10 @@ use constant NEWRELIC_ROOT_SEGMENT => 0;
 use constant NEWRELIC_AUTOSCOPE    => 1;
 
 # ABSTRACT: Procedural interface for NewRelic APM
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
-our $ffi;
+my $ffi;
 
 BEGIN {
   $ffi = FFI::Platypus->new;
@@ -46,12 +46,12 @@ BEGIN {
 
 $ffi->attach( newrelic_init => [ 'string', 'string', 'string', 'string' ] => 'int' => sub {
   my($xsub, $license_key, $app_name, $app_language, $app_language_version) = @_;
-  
+
   $license_key          ||= $ENV{NEWRELIC_LICENSE_KEY}          || '';
   $app_name             ||= $ENV{NEWRELIC_APP_NAME}             || 'AppName';
   $app_language         ||= $ENV{NEWRELIC_APP_LANGUAGE}         || 'perl';
   $app_language_version ||= $ENV{NEWRELIC_APP_LANGUAGE_VERSION} || $];
-  
+
   $xsub->($license_key, $app_name, $app_language, $app_language_version);
 });
 
@@ -76,7 +76,7 @@ $ffi->attach( newrelic_segment_generic_begin              => [ 'long', 'long', '
 # do much, as that appears to be the default.  For the Procedural version we pass in NULL by default, but you
 # can override with another symbol if you want.  Needs to be a C symbol though, not a Perl code ref.
 $ffi->attach( newrelic_segment_datastore_begin => [ 'long', 'long', 'string', 'string', 'string', 'string', 'opaque' ] => 'long' );
-         
+
 
 $ffi->attach( newrelic_segment_external_begin => [ 'long', 'long', 'string', 'string' ] => 'long' );
 $ffi->attach( newrelic_segment_end            => [ 'long', 'long' ] => 'int' );
@@ -112,17 +112,22 @@ NewRelic::Agent::FFI::Procedural - Procedural interface for NewRelic APM
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
  use NewRelic::Agent::FFI::Procedural;
  
+ # enable embedded mode:
+ newrelic_register_message_handler newrelic_message_handler;
+ 
+ # initalize:
  newrelic_init
    'abc123'     # license key
    'REST API'   # app name
  ;
  
+ # use it:
  my $tx = newrelic_transaction_begin;
  ...
  my $status = newrelic_transaction_end $tx;
@@ -323,9 +328,10 @@ Begins a new generic segment.  C<$parent_seg> is a parent segment id (C<undef> n
 
 Begins a new generic segment.  C<$parent_seg> is a parent segment id (C<undef> no parent).  C<$name> is a string.
 
-=head2 begin_datastore_segment
+=head2 newrelic_segment_datastore_begin
 
- my $seg = $agent->begin_datastore_segment($tx, $parent_seg, $table, $operation, $sql, $sql_trace_rollup_name);
+ my $seg = newrelic_segment_datastore_begin $tx, $parent_seg, $table, $operation, $sql, $sql_trace_rollup_name;
+ my $seg = newrelic_segment_datastore_begin $tx, $parent_seg, $table, $operation, $sql, $sql_trace_rollup_name, $sql_obfuscator;
 
 Begins a new datastore segment.  C<$parent_seg> is a parent segment id (C<undef> no parent).  C<$operation> should be
 one of C<select>, C<insert>, C<update> or C<delete>.
